@@ -342,7 +342,7 @@ cpp_java_assist_create_scope_completion_cache (CppJavaAssist *assist,
 											   IANJUTA_SYMBOL_FIELD_SIMPLE,
 											   contexts[0],
 											   FALSE,
-											   TRUE,
+											   IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC,
 											   TRUE,
 											   1,
 											   -1,
@@ -356,7 +356,7 @@ cpp_java_assist_create_scope_completion_cache (CppJavaAssist *assist,
 						ianjuta_symbol_manager_get_members(assist->priv->isymbol_manager,
 														   IANJUTA_SYMBOL(symbol),
 														   IANJUTA_SYMBOL_FIELD_SIMPLE,
-														   TRUE, NULL);
+														   NULL);
 					if (members && ianjuta_iterable_get_length (members, NULL))
 					{
 						gboolean found = FALSE;
@@ -389,7 +389,7 @@ cpp_java_assist_create_scope_completion_cache (CppJavaAssist *assist,
 						ianjuta_symbol_manager_get_members(assist->priv->isymbol_manager,
 														   IANJUTA_SYMBOL(symbol),
 														   IANJUTA_SYMBOL_FIELD_SIMPLE,
-														   TRUE, NULL);
+														   NULL);
 					if (members)
 					{
 						assist->priv->completion_cache =
@@ -518,7 +518,7 @@ cpp_java_assist_create_word_completion_cache (CppJavaAssist *assist)
 			if (file != NULL)
 			{				
 				IAnjutaIterable* iter_file = ianjuta_symbol_manager_search_file (assist->priv->isymbol_manager,
-																				 IANJUTA_SYMBOL_TYPE_MAX,
+																				 IANJUTA_SYMBOL_TYPE_UNDEF,
 																				 TRUE,
 																				 IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
 																				 pattern, file, -1, -1, NULL);
@@ -534,17 +534,17 @@ cpp_java_assist_create_word_completion_cache (CppJavaAssist *assist)
 		
 		IAnjutaIterable* iter_project = 
 			ianjuta_symbol_manager_search_project (assist->priv->isymbol_manager,
-										   IANJUTA_SYMBOL_TYPE_MAX,
+										   IANJUTA_SYMBOL_TYPE_UNDEF,
 										   TRUE,
 										   IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
-										   pattern, -1, -1, NULL);
+										   pattern, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1, NULL);
 		
 		IAnjutaIterable* iter_globals = 
 			ianjuta_symbol_manager_search_system (assist->priv->isymbol_manager,
-										   IANJUTA_SYMBOL_TYPE_MAX,
+										   IANJUTA_SYMBOL_TYPE_UNDEF,
 										   TRUE,
 										   IANJUTA_SYMBOL_FIELD_SIMPLE|IANJUTA_SYMBOL_FIELD_TYPE,
-										   pattern, -1, -1, NULL);
+										   pattern, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC, -1, -1, NULL);
 		g_free (pattern);
 
 		if (iter_project) 
@@ -652,14 +652,22 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter)
 			const gchar* name = ianjuta_symbol_get_name(symbol, NULL);
 			if (name != NULL)
 			{
-				const gchar* args = ianjuta_symbol_get_args(symbol, NULL);
+								const gchar* args = ianjuta_symbol_get_args(symbol, NULL);
 				const gchar* rettype = ianjuta_symbol_get_returntype (symbol, NULL);
 				gchar* print_args;
 				gchar* separator;
-				gchar* white_name = g_strnfill (strlen(name) + 1, ' ');
+				gchar* white_name;
+				gint white_count = 0;
+
+				if (!rettype)
+					rettype = "";
+				else
+					white_count += strlen(rettype) + 1;
 				
+				white_count += strlen(name) + 1;
+				
+				white_name = g_strnfill (white_count, ' ');
 				separator = g_strjoin (NULL, ", \n", white_name, NULL);
-				//DEBUG_PRINT ("Separator: \n%s", separator);
 				
 				gchar** argv;
 				if (!args)
@@ -667,9 +675,6 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter)
 				
 				argv = g_strsplit (args, ",", -1);
 				print_args = g_strjoinv (separator, argv);
-
-				if (!rettype)
-					rettype = "";
 				
 				gchar* tip = g_strdup_printf ("%s %s %s", rettype, name, print_args);
 				
@@ -680,6 +685,7 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter)
 				g_free (print_args);
 				g_free (separator);
 				g_free (white_name);
+
 			}
 			else
 				break;
@@ -733,7 +739,7 @@ cpp_java_assist_show_calltip (CppJavaAssist *assist, gchar *call_context,
 									   IANJUTA_SYMBOL_TYPE_METHOD|
 									   IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
 									   TRUE, IANJUTA_SYMBOL_FIELD_SIMPLE,
-									   call_context,
+									   call_context, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC,
 									   max_completions, -1, NULL);
 	if (iter_project)
 	{
@@ -749,7 +755,7 @@ cpp_java_assist_show_calltip (CppJavaAssist *assist, gchar *call_context,
 									   IANJUTA_SYMBOL_TYPE_METHOD|
 									   IANJUTA_SYMBOL_TYPE_MACRO_WITH_ARG,
 									   TRUE, IANJUTA_SYMBOL_FIELD_SIMPLE,
-									   call_context, 
+									   call_context, IANJUTA_SYMBOL_MANAGER_SEARCH_FS_PUBLIC,
 									   max_completions, -1, NULL);
 	if (iter_global)
 	{
@@ -886,6 +892,10 @@ on_assist_chosen (IAnjutaEditorAssist* iassist, gint selection,
 	gboolean add_brace_after_func = FALSE;
 	
 	//DEBUG_PRINT ("assist-chosen: %d", selection);
+
+	g_return_if_fail (assist != NULL);
+	g_return_if_fail (assist->priv != NULL);
+	g_return_if_fail (assist->priv->completion_cache != NULL);
 	
 	if (assist->priv->completion_cache->cache)
 		tag = g_list_nth_data (assist->priv->completion_cache->cache,
